# Contributing to Eradiate

Thank you for considering contributing to Eradiate. We welcome your input,
whether it is:

- Opening or participating in a discussion about Eradiate
- Proposing new features
- Reporting a bug
- Submitting a fix
- Contributing a new feature

## Asking about Eradiate

Our [Discussions forum](https://github.com/eradiate/eradiate/discussions) should
be used to ask about how to use Eradiate, discuss its features, and more
generally to talk about anything that is not strictly speaking an issue with the
code.

## Report bugs using the GitHub issue tracker

We use GitHub issues to track public bugs. Report a bug by
[opening a new issue](https://github.com/eradiate/eradiate/issues/new/choose).

Please be sure to provide details as requested by the issue template. Write bug
reports with detail, background, and sample code.

## We develop with GitHub

We use GitHub to host code, to track issues and feature requests, as well as
accept pull requests.

**Most code changes happen through pull requests**
([more detail about our workflow here](https://docs.github.com/en/get-started/quickstart/github-flow)).
To propose a change to the codebase, please:

1. Fork the repository and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Issue the pull request.

**Please be sure to read our
[contribution guidelines](https://eradiate.readthedocs.io/en/latest/rst/contributing.html).**

## Any contributions you make will be under the LGPLv3 Software License

In short, when you submit code changes, your submissions are understood to be
under the same [LGPLv3 License](https://github.com/eradiate/eradiate/blob/main/LICENSE)
that covers the project. Feel free to contact the maintainers if that's a
concern.
